import pygame

import general
import image_cache

class AnimationType:
	def __init__(self, images, delay, center):
		self.images = images
		self.delay = delay
		self.center = center
	
	def create_vertical_flipped(self):
		new_image_set = map(lambda image:pygame.transform.flip(image,True,False),self.images)
		new_center = general.Vector2(self.images[0].get_width()-self.center.x,self.center.y)
		return AnimationType(new_image_set, self.delay, new_center)
	
	@staticmethod
	def create_by_name(base_name, delay, center):
		images = []
		i = 1
		while True:
			try:
				images.append(image_cache.get_cache_image(base_name+str(i)))
			except:
				break
			i+=1
		return AnimationType(images, delay, center)

class AnimationInstance:
	def __init__(self, animation_type):
		self.image_index = 0
		self.accumulated_time = 0
		self.animation_type = animation_type
	def do_frame(self, time_delta):
		self.accumulated_time += time_delta
		frames = int(self.accumulated_time/self.animation_type.delay)
		if frames > 0:
			self.accumulated_time -= frames*self.animation_type.delay
			self.image_index = (self.image_index + frames) % len(self.animation_type.images)
	def get_image(self):
		return self.animation_type.images[self.image_index]
