import math

import pygame

import config
import general

class Camera:
	def __init__(self,bounds):
		self.mouse_pan = general.Vector2()
		self.keyboard_pan = general.Vector2()
		self.bounds = bounds
		self.position = self.tile_to_offset(general.Vector2(bounds[0]/2.0,bounds[1]/2.0))
	
	def mouse_move(self, new_position):
		if new_position[0] <= config.game_area[0] + config.camera_pan_screen_area_size:
			self.mouse_pan.x = -1.0 * (config.camera_pan_screen_area_size+config.game_area[0]-new_position[0]) / config.camera_pan_screen_area_size
		elif new_position[0] >= config.game_area[2] - config.camera_pan_screen_area_size:
			self.mouse_pan.x = +1.0 * (new_position[0] + config.camera_pan_screen_area_size - config.game_area[2]) / config.camera_pan_screen_area_size
		else:
			self.mouse_pan.x = 0
		
		if new_position[1] <= config.game_area[1] + config.camera_pan_screen_area_size:
			self.mouse_pan.y = -1.0 * (config.camera_pan_screen_area_size+config.game_area[1]-new_position[1]) / config.camera_pan_screen_area_size
		elif new_position[1] >= config.game_area[3] - config.camera_pan_screen_area_size:
			self.mouse_pan.y = +1.0 * (new_position[1]+config.camera_pan_screen_area_size-config.game_area[3]) / config.camera_pan_screen_area_size
		else:
			self.mouse_pan.y = 0

	def key_down(self, key):
		if key == pygame.K_DOWN:
			self.keyboard_pan.y = 1
		if key == pygame.K_UP:
			self.keyboard_pan.y = -1
		if key == pygame.K_LEFT:
			self.keyboard_pan.x = -1
		if key == pygame.K_RIGHT:
			self.keyboard_pan.x = 1
	def key_up(self, key):
		if key == pygame.K_DOWN or key == pygame.K_UP:
			self.keyboard_pan.y = 0
		if key == pygame.K_LEFT or key == pygame.K_RIGHT:
			self.keyboard_pan.x = 0
	
	def out_of_screen(self):
		self.mouse_pan = general.Vector2()
		self.keyboard_pan = general.Vector2()
	
	def do_frame(self, time_delta):
		self.position += self.mouse_pan * (time_delta * config.tile_size[0] * config.camera_mouse_pan_speed)
		self.position += self.keyboard_pan * (time_delta * config.tile_size[0] * config.camera_keyboard_pan_speed)
		
		#bounds check:
		screen_center = (config.screen_size[0]/2,config.screen_size[1]/2)
		tile_at_center = self.translate_screen_to_tile(screen_center)
		
		if tile_at_center.x < 0:
			tile_at_center.x = 0
		elif tile_at_center.x > self.bounds[0]:
			tile_at_center.x = self.bounds[0]
	
		if tile_at_center.y < 0:
			tile_at_center.y = 0
		elif tile_at_center.y > self.bounds[1]:
			tile_at_center.y = self.bounds[1]
		
		self.position = self.tile_to_offset(tile_at_center)
		
	def translate_screen_to_tile(self,coords):
		#translation:
		x = coords[0] + self.position.x - config.screen_size[0]/2
		y = coords[1] + self.position.y - config.screen_size[1]/2
		#scaling:
		x = float(x) / config.tile_size[0]
		y = float(y) / config.tile_size[1]
		#"rotating":
		return general.Vector2(x-y, x+y)
	
	def tile_to_offset(self, coords):
		#"rotating":
		tile_x,tile_y = coords.x+coords.y, coords.y-coords.x
		#scaling:
		scaled_x = config.tile_size[0]/2*tile_x
		scaled_y = config.tile_size[1]/2*tile_y
		return general.Vector2(scaled_x,scaled_y)
	
	def translate_tile_to_screen(self, coords):
		scaled = self.tile_to_offset(coords)
		
		#translation:
		#int() - converting position to pixels
		x = scaled.x - int(self.position.x) + config.screen_size[0]/2
		y = scaled.y - int(self.position.y) + config.screen_size[1]/2
		return general.Vector2(x,y)
	
