import general

#===================================
#{ Splash
#===================================

splash_time = 5.0
splash_image = "car.jpg"
splash_fade_time = 1.0

#===================================
#{ GUI
#===================================

#: [pixels]
screen_size = (800,600)
is_full_screen = False

game_area = (0,0,screen_size[0],screen_size[1]-50)

#: [pixels]
tile_size = (140,70)

#Camera:
#: [pixels]
camera_pan_screen_area_size = 85
#: [(tile width)/second]
camera_mouse_pan_speed = 4
#: [(tile width)/second]
camera_keyboard_pan_speed = 5


class LevelConfig:
	description = "Generic level"
	
	#===================================
	#{ level_structure
	#===================================
	
	size = (15,15)
	
	portals = [ #Start position, start direction
		(general.Vector2(0,size[0]/2.0), general.Vector2(1,0)),
		]
	
	gayness_target = 100
	
	#===================================
	#{ People
	#===================================

	#:[1 grass unit / second]
	degradation_factor = 0.38

	#:[tiles/second]
	person_speed = 1.5

	#[seconds]
	person_walk_distance = 5
	#[people/second] Minimal and maximal time to the next person
	minimum_person_rate = 1/10.0
	maximum_person_rate = 1/1.0

	money_per_visitor = 15

	#===================================
	#{ Gameplay
	#===================================

	grass_gayness = 1
	flowers_min_gayness = -1
	flowers_max_gayness = 3
	concrete_gayness = 0.5
	plaza_gayness = 1

	start_money = 500

	grass_cost = 5
	flowers_cost = 12
	concrete_cost = 20
	plaza_cost = 50
	
	flowers_enabled = True
	concrete_enabled = True
	plaza_enabled = True

class Tutorial1(LevelConfig):
	description = "Tutorial 1: How to play"
	html = "Welcome to 'Lawning Day'.<br>"
	html += "In the next few tutorial levels, you will learn to play the game.<br><br>"
	html += "Your goal is to make your park reach a lovelyness level of 10.<br>"
	html += "You do that by creating grass tiles:"
	html += "<ul><li>Each grass tile adds 1 lovelyness to your park, at the cost of 5.</li>"
	html += "<li>If a grass tile is destroyed, it will provide less lovelyness.</li>"
	html += "<li>If a grass tile is fully destroyed, being just ground, it will not<br>"
	html += "provide any lovelyness and the money spent on it is 'wasted'.</li><ul>"
	size = (5,5)
	portals = [
		(general.Vector2(0,size[0]/2.0), general.Vector2(1,0)),
		]
	person_walk_distance = 1.5
	money_per_visitor = 4.5
	gayness_target = 10
	degradation_factor = 0.22
	
	minimum_person_rate = 1/1.5
	maximum_person_rate = 1/1.0
	start_money = 30
	
	flowers_enabled = False
	concrete_enabled = False
	plaza_enabled = False

class Tutorial2(Tutorial1):
	description = "Tutorial 2: Income"
	html = "As you might have noticed, your money is limited.<br>"
	html += "You gain money from visitors to your park:<br>each person brings some money upon entrance.<br><br>"
	html += "The more lovely your park is, the more people will come to your park.<br>"
	minimum_person_rate = 1/1.5
	maximum_person_rate = 2/1.0
	start_money = 0
	gayness_target = 15

class Tutorial3(Tutorial2):
	description = "Tutorial 3: Introducing concrete blocks"
	html = "The entrance points are not very useful for growing grass:<br>"
	html += "People are always stepping on them.<br><br>"
	html += "Building a concrete block will cost more (20), and is less lovely than grass,<br>"
	html += "but it is indestructible. Use the concrete button on the bottom.<br><br>"
	html += "Don't forget to keep your park lovely to bring in people and money."
	concrete_enabled = True
	size = (5,5)
	portals = [
		(general.Vector2(0,           size[1]/2.0), general.Vector2(1,0)),
		(general.Vector2(size[0],     size[1]/2.0), general.Vector2(-1,0)),
		(general.Vector2(size[0]/2.0, 0),           general.Vector2(0,1)),
		(general.Vector2(size[0]/2.0, size[1]),     general.Vector2(0,-1)),
		]
	gayness_target = 17.5

class Tutorial4(Tutorial3):
	description = "Tutorial 4: Introducing flowers"
	html = "To make your park really lovely, you can build flowers.<br>"
	html += "At a relatively low cost(12), they bring a bonus of 3 to your park's lovelyness.<br><br>"
	html += "The catch is, that when stepped on, they become flower-trash,<br>"
	html += "which is not a pretty sight (-1 lovelyness)."
	flowers_enabled = True
	gayness_target = 27.5

class Tutorial5(Tutorial4):
	description = "Tutorial 5: Introducing plazas"
	html = "If you have really lots of moneys, you can spend it on Plaza tiles.<br>"
	html += "Their great cost(50) is compensated by being beautiful just like nature (grass),<br>"
	html += "and indistructible like concrete.<br><br>"
	html += "Luckily - the people on this level are richer."
	plaza_enabled = True
	gayness_target = 50
	money_per_visitor = 9.5

class Level1(LevelConfig):
	description = "Level 1 - Green Park"
	html = '<ul><li>"What do you mean we have no parks in the city? Just last year we spent<br>'
	html += 'twenty bucks for that damn lawn on arlington street!"</li>'
	html += '<li>"Yes, mayor, but the people there stepped on it and nothing was left of it.."</li>'
	html += '<li>"You will have to do then with only 10 bucks!"</li>'
	html += '<li>"But the people need a green park.."</li>'
	html += '<li>"And the city need the money. Find another way to build your park!"</li></ul>'
	start_money = 10
	size = (10,10)
	portals = [
		(general.Vector2(0,           size[1]/2.0), general.Vector2(1,0)),
		]
	gayness_target = 20
	
	minimum_person_rate = 1/10.0
	maximum_person_rate = 1/1.0
	person_walk_distance = 1.5
	money_per_visitor = 2.5

class Level2(Level1):
	description = "Level 2 - Linkin' Day"
	html = '<ul><li>"Did you hear? Linkin\' day is coming to town! Everyone will be there!"</li>'
	html += '<li>"Really? <b>Awesome!!</b> I\'m gonna tell all my friends!"</li></ul>'
	start_money = 10
	size = (10,10)
	portals = [
		(general.Vector2(0,0.5), general.Vector2(1,0)),
		(general.Vector2(0,1.5), general.Vector2(1,0)),
		(general.Vector2(0,2.5), general.Vector2(1,0)),
		(general.Vector2(0,3.5), general.Vector2(1,0)),
		(general.Vector2(0,4.5), general.Vector2(1,0)),
		(general.Vector2(0,5.5), general.Vector2(1,0)),
		(general.Vector2(0,6.5), general.Vector2(1,0)),
		(general.Vector2(0,7.5), general.Vector2(1,0)),
		(general.Vector2(0,8.5), general.Vector2(1,0)),
		(general.Vector2(0,9.5), general.Vector2(1,0)),
		]
	gayness_target = 25
	
	minimum_person_rate = 10/1.0
	maximum_person_rate = 20/1.0
	person_walk_distance = 5
	money_per_visitor = 1

class Level3(Level1):
	description = "Level 3 - Garbage disposal plant"
	html = '<ul><li>"What do we need garbage for?"</li>'
	html += '<li>"The kids here like it. They have been living around this disposal plant<br>'
	html += 'for many years now, so thats what they like."</li>'
	html += '<li>"But how will i tell my park engineer to build <i>garbage</i>?"</li></ul>'
	start_money = 50
	size = (20,20)
	portals = [
		(general.Vector2(0,           size[1]/2.0), general.Vector2(1,0)),
		(general.Vector2(size[0],     size[1]/2.0), general.Vector2(-1,0)),
		(general.Vector2(size[0]/2.0, 0),           general.Vector2(0,1)),
		(general.Vector2(size[0]/2.0, size[1]),     general.Vector2(0,-1)),
		]
	gayness_target = 500
	
	minimum_person_rate = 1/5.0
	maximum_person_rate = 10/1.0
	
	flowers_min_gayness = 10
	flowers_max_gayness = 0
	
	person_walk_distance = 5
	money_per_visitor = 1

class Level4(Level1):
	description = "Level 4 - Going nuts"
	html = '<ul><li>"Build a-<b>what</b>??"</li>'
	html += '<li>"A Long-Park. It will allow people from all over the city to come."</li>'
	html += '<li>"Who will want to come there?"</li>'
	html += '<li>"You will see..."</li></ul>'
	start_money = 1000
	size = (50,10)
	portals = [
		(general.Vector2(0,           size[1]/2.0), general.Vector2(1,0)),
		(general.Vector2(size[0],     size[1]/2.0), general.Vector2(-1,0)),
		]
	gayness_target = 500
	
	minimum_person_rate = 1/100.0
	maximum_person_rate = 20/1.0
	person_walk_distance = 25
	money_per_visitor = 1
	
all_levels = [Tutorial1,Tutorial2,Tutorial3,Tutorial4,Tutorial5,Level1,Level2,Level3,Level4]
