import os

import pygame

def get_data_folder():
	folder = os.path.abspath(os.path.dirname(__file__))
	for i in range(2):
		if os.path.isdir(os.path.join(folder,'data')):
			return os.path.join(folder,'data')
		folder = os.path.split(folder)[0]

def get_resource_path(filename):
	folder = get_data_folder()
	return os.path.join(folder,filename.lower())

def _load_image(image_name,per_pixel_alpha = False):
	fullpath = get_resource_path("%s.png" % image_name)
	if per_pixel_alpha:
		return pygame.image.load(fullpath).convert_alpha()
	else:
		return pygame.image.load(fullpath)

image_cache = {}
def get_cache_image(name,per_pixel_alpha = False):
	if name not in image_cache:
		image_cache[name] = _load_image(name,per_pixel_alpha)
	return image_cache[name]

def _create_tile(tilename,per_pixel_alpha):
	mask_image = get_cache_image('mask')
	tile_image = _load_image(tilename,per_pixel_alpha)
	if tile_image.get_width() != mask_image.get_width() or tile_image.get_height() != mask_image.get_height():
		raise Exception("Tile image not in the right size")
	if not per_pixel_alpha:
		tile_image.set_colorkey((255,0,255))
	for x in xrange(tile_image.get_width()):
		for y in xrange(tile_image.get_height()):
			if mask_image.get_at((x,y))[:3] == (0,0,0):
				if per_pixel_alpha:
					tile_image.set_at((x,y),(0,0,0,0))
				else:
					tile_image.set_at((x,y),(255,0,255))
	return tile_image

tile_cache = {}
def get_cache_tile(tilename,per_pixel_alpha = False):
	if tilename not in tile_cache:
		tile_cache[tilename] = _create_tile(tilename,per_pixel_alpha)
	return tile_cache[tilename]