import sys
import time

import pygame
import pgu.gui

import level
import config
import screen
import music

starting_screen_index = "splash"
current_level = None
end = False

def load_level(index):
	global current_level
	global end
	
	pgu_app = pgu.gui.App()
	pgu_container = pgu.gui.Container(align=-1,valign=-1)
	
	if index == None or index == "main_menu":
		current_level = screen.MainMenu(pgu_container)
	elif index == "splash":
		current_level = screen.SplashScreen(pgu_container)
	elif index == "win":
		current_level = screen.WinScreen(pgu_container)
	elif index == "options":
		current_level = screen.OptionsScreen(pgu_container)
	elif index == "quit":
		current_level = screen.SplashScreen(pgu_container) #whatever
		end = True
	else:
		current_level = level.Level(config.all_levels[index](),pgu_container)
	
	current_level.pgu_app = pgu_app
	current_level.refresh_gui()
	
def do_frame(time_delta):
	global current_level
	
	if current_level.has_music:
		music.check_music()
	current_level.do_frame(time_delta)
	if current_level.done:
		load_level(current_level.next_screen)
	
def draw():
	global pygame_screen
	
	if current_level.background_color != None:
		pygame_screen.fill(current_level.background_color)
	
	current_level.draw(pygame_screen)
	
	current_level.pgu_app.paint(pygame_screen)
	
	pygame.display.flip()
	

def handle_event(event):
	global end
	
	#quit events
	if event.type == pygame.QUIT:
		end = True
	
	current_level.pgu_app.event(event)
	
	if event.type == pygame.KEYDOWN:
		current_level.key_down(event.key)
	if event.type == pygame.KEYUP:
		current_level.key_up(event.key)
	if event.type == pygame.MOUSEMOTION:
		if (event.pos[0] < config.game_area[0] or
			event.pos[1] < config.game_area[1] or
			event.pos[0] > config.game_area[2] or
			event.pos[1] > config.game_area[3]):
			current_level.out_of_screen()
		else:
			current_level.mouse_move(event.pos)
	if event.type == pygame.MOUSEBUTTONDOWN:
		current_level.mouse_click(event.pos)
	if event.type == pygame.ACTIVEEVENT:
		if event.gain == 0:
			current_level.out_of_screen()

last_time = time.time()
def main():
	global pygame_screen,last_time
	pygame.init()
	music.init()
	pygame_screen = pygame.display.set_mode(config.screen_size)
	
	load_level(starting_screen_index)
	
	while not end:
		event_list = pygame.event.get()
		for event in event_list:
			handle_event(event)
		draw()
		
		#Do frame
		current_time = time.time()
		time_delta = current_time - last_time
		do_frame(time_delta)
		last_time = current_time
		
	pygame.quit()

if __name__ == "__main__":
	main()
