import time

import pygame
import pgu

import config
import image_cache
import high_scores
import main

class Screen:
	def __init__(self,pgu_container):
		self.done = False
		self.next_screen = None
		self.background_color = (255,255,255)
		self.background_image = None
		self.has_music = True
		self.pgu_container = pgu_container
	def refresh_gui(self):
		self.pgu_app.init(self.pgu_container)
	def go_to_main_menu(self):
		self.done = True
		self.next_screen = "main_menu"
	def mouse_move(self, position):
		pass
	def key_down(self, key):
		pass
	def key_up(self, key):
		pass
	def out_of_screen(self):
		pass
	def mouse_click(self, position):
		pass
	
	def do_frame(self, time_delta):
		pass
	def draw(self,target):
		if self.background_image != None:
			position = ((config.screen_size[0]-self.background_image.get_width()) /2,
						(config.screen_size[1]-self.background_image.get_height())/2)
			target.blit(self.background_image,position)

class SplashScreen(Screen):
	def __init__(self,pgu_container):
		Screen.__init__(self,pgu_container)
		self.has_music = False
		self.start_time = time.time()
		self.image = pygame.image.load(image_cache.get_resource_path(config.splash_image))
		self.background_color = (0,0,0)
		self.played = False
	def do_frame(self, time_delta):
		if time.time() - self.start_time > config.splash_time:
			self.done = True
		if time.time() - self.start_time > config.splash_fade_time*0.5 and self.played == False:
			self.played = True
			pygame.mixer.Sound(image_cache.get_resource_path("carhorntwice.wav")).play()
	def mouse_click(self, position):
		self.done = True
	def key_down(self, key):
		self.done = True
	def draw(self,target):
		time_passed = time.time() - self.start_time
		if time_passed < config.splash_fade_time:
			trans = time_passed / config.splash_fade_time
		elif config.splash_time-time_passed < config.splash_fade_time:
			trans = (config.splash_time-time_passed) / config.splash_fade_time
		else:
			trans = 1.0
		self.image.set_alpha(trans*255)
		position = ((config.screen_size[0]-self.image.get_width()) /2,
					(config.screen_size[1]-self.image.get_height())/2)
		target.blit(self.image,position)

class OptionsScreen(Screen):
	def __init__(self, pgu_container):
		Screen.__init__(self,pgu_container)
		
		menu_table = pgu.gui.table.Table()
		def add_to_menu(widget, align=0):
			menu_table.tr()
			menu_table.td(widget, align=align)
		
		add_to_menu(pgu.gui.basic.Spacer(1,200))
		
		if config.is_full_screen:
			button = pgu.gui.button.Button(pgu.gui.basic.Label("Set windowed"))
			button.connect(pgu.gui.CLICK,self.set_windowed)
			add_to_menu(button)
		else:
			button = pgu.gui.button.Button(pgu.gui.basic.Label("Set fullscreen"))
			button.connect(pgu.gui.CLICK,self.set_full_screen)
			add_to_menu(button)
		
		add_to_menu(pgu.gui.basic.Spacer(1,30))
		
		button = pgu.gui.button.Button(pgu.gui.basic.Label("Set 800x600"))
		button.connect(pgu.gui.CLICK,self.set_resolution,(800,600))
		add_to_menu(button)
		
		add_to_menu(pgu.gui.basic.Spacer(1,30))
		
		button = pgu.gui.button.Button(pgu.gui.basic.Label("Set 1024x768"))
		button.connect(pgu.gui.CLICK,self.set_resolution,(1024,768))
		add_to_menu(button)
		
		add_to_menu(pgu.gui.basic.Spacer(1,30))
		
		button = pgu.gui.button.Button(pgu.gui.basic.Label("Set 1280x1024"))
		button.connect(pgu.gui.CLICK,self.set_resolution,(1280,1024))
		add_to_menu(button)
		
		add_to_menu(pgu.gui.basic.Spacer(1,30))
		
		button = pgu.gui.button.Button(pgu.gui.basic.Label("Back to menu"))
		button.connect(pgu.gui.CLICK,self.finish)
		add_to_menu(button)
		
		centering_table = pgu.gui.table.Table()
		centering_table.tr()
		centering_table.td(pgu.gui.basic.Spacer(config.screen_size[0],1), align=0)
		centering_table.tr()
		centering_table.td(menu_table, align=0)
		
		pgu_container.add(centering_table,0,(config.screen_size[1]-600)/2)
	
	def set_resolution(self, res):
		config.screen_size = res
		config.game_area = (0,0,res[0],res[1]-50)
		self.update()
	
	def set_full_screen(self):
		config.is_full_screen = True
		self.update()
	
	def set_windowed(self):
		config.is_full_screen = False
		self.update()
	
	def update(self):
		if config.is_full_screen:
			flag = pygame.FULLSCREEN
		else:
			flag = 0
		main.surface = pygame.display.set_mode(config.screen_size,flag)
		
		self.done = True
		self.next_screen = "options"
	
	def finish(self):
		self.done = True

class MainMenu(Screen):
	def __init__(self, pgu_container):
		Screen.__init__(self,pgu_container)
		self.background_image = pygame.image.load(image_cache.get_resource_path("menu.png"))
		
		self.high_score_label = pgu.gui.basic.Label("*"*40)
		
		menu_table = pgu.gui.table.Table()
		def add_to_menu(widget, align=0):
			menu_table.tr()
			menu_table.td(widget, align=align)
		
		add_to_menu(pgu.gui.basic.Spacer(1,200))
		
		add_to_menu(pgu.gui.basic.Label("Select level:"), align=-1)
		
		add_to_menu(pgu.gui.basic.Spacer(1,5))
		
		self.level_selector = pgu.gui.select.Select(value=0)
		for i in range(len(config.all_levels)):
			self.level_selector.add(config.all_levels[i].description, i)
			level = config.all_levels[i]
			time = high_scores.check(level)
			if time == None:
				break
		self.level_selector.value = i
		self.level_selector.connect(pgu.gui.CHANGE,self.update_high_score_label)
		self.update_high_score_label()
		add_to_menu(self.level_selector, align=0)
		
		add_to_menu(pgu.gui.basic.Spacer(1,8))
		add_to_menu(self.high_score_label)
		add_to_menu(pgu.gui.basic.Spacer(1,32))
		
		start_button = pgu.gui.button.Button(pgu.gui.basic.Image(image_cache.get_cache_image("start_button",True)))
		start_button.connect(pgu.gui.CLICK,self.start_game_command)
		add_to_menu(start_button, align=0)
		
		add_to_menu(pgu.gui.basic.Spacer(1,100))
		options_button = pgu.gui.button.Button(pgu.gui.basic.Label(("Options")))
		options_button.connect(pgu.gui.CLICK,self.options_command)
		add_to_menu(options_button, align=0)
		
		add_to_menu(pgu.gui.basic.Spacer(1,20))
		quit_button = pgu.gui.button.Button(pgu.gui.basic.Image(image_cache.get_cache_image("quit_button",True)))
		quit_button.connect(pgu.gui.CLICK,self.quit_command)
		add_to_menu(quit_button, align=0)
		
		centering_table = pgu.gui.table.Table()
		centering_table.tr()
		centering_table.td(pgu.gui.basic.Spacer(config.screen_size[0],1), align=0)
		centering_table.tr()
		centering_table.td(menu_table, align=0)
		
		pgu_container.add(centering_table,0,(config.screen_size[1]-600)/2)
	
	def update_high_score_label(self):
		level = config.all_levels[self.level_selector.value]
		time = high_scores.check(level)
		if time == None:
			self.high_score_label.value = "You must achieve this level to continue!"
		else:
			self.high_score_label.value = "Fastest time: %.2f seconds" % time
	
	def start_game_command(self):
		self.next_screen = self.level_selector.value
		self.done = True
	def quit_command(self):
		self.next_screen = "quit"
		self.done = True
	def options_command(self):
		self.next_screen = "options"
		self.done = True

class WinScreen(Screen):
	def __init__(self,pgu_container):
		Screen.__init__(self,pgu_container)
		self.background_image = pygame.image.load(image_cache.get_resource_path("win.png"))
		
		main_menu_button=pgu.gui.button.Button("Back to menu")
		main_menu_button.connect(pgu.gui.CLICK,self.go_to_main_menu)
		centering_table = pgu.gui.table.Table()
		centering_table.tr()
		centering_table.td(pgu.gui.basic.Spacer(config.screen_size[0],1), align=0)
		centering_table.tr()
		centering_table.td(main_menu_button, align=0)
		pgu_container.add(centering_table,0,450+(config.screen_size[1]-600)/2)
